@@ -2,25 +2,8 @@ from __future__ import with_statement
 import tempfile
 import os
 import shutil
-import virtualenv
 from contextlib import contextmanager
-
-class ChangedWorkingDirectory(object):
-    def __init__(self, directory):
-        self._directory = directory
-        self._original_directory = os.getcwd()
-
-    def __enter__(self):
-        # Change the directory to the new cwd
-        directory = self._directory
-        # Change to the new directory
-        os.chdir(directory)
-        # Return the directory
-        return directory
-
-    def __exit__(self, ex_type, ex_value, traceback):
-        # Return back to normal
-        os.chdir(self._original_directory)
+from virtstrap.utils import ChangedWorkingDirectory, in_directory
 
 class TempDirectory(object):
     def __init__(self):
@@ -58,18 +41,9 @@ def temp_directory():
     with TempDirectory() as temp_dir:
         yield temp_dir
 
-@contextmanager
-def in_directory(directory):
-    """Context manager for changing CWD to a directory
-
-    Don't use this if you plan on writing files to the directory.
-    This does not delete anything. It is purely to change the CWD
-    """
-    with ChangedWorkingDirectory(directory) as directory:
-        yield directory
-
 @contextmanager
 def temp_virtualenv(*args, **kwargs):
+    import virtualenv
     with in_temp_directory() as temp_dir:
         virtualenv.create_environment(temp_dir, site_packages=False)
         yield temp_dir
